@@ -1,18 +1,13 @@
 package Net::DNS::RR::TKEY;
-#
-# $Id: TKEY.pm 979 2012-01-27 08:43:38Z willem $
-#
-use strict;
-BEGIN {
-    eval { require bytes; }
-}
-use vars qw(@ISA $VERSION);
 
+use strict;
+use vars qw(@ISA);
+
+use Net::DNS::Packet;
 use Digest::HMAC_MD5;
 use MIME::Base64;
 
-@ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$LastChangedRevision: 979 $)[1];
+@ISA = qw(Net::DNS::RR);
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -20,22 +15,30 @@ sub new {
 	# if we have some data then we are parsing an incoming TKEY packet
 	# see RFC2930 for the packet format
 	if ($self->{"rdlength"} > 0) {
-		($self->{"algorithm"}, $offset) = Net::DNS::Packet::dn_expand($data, $offset);
+		my $alg;
+		($alg, $offset) = Net::DNS::Packet::dn_expand($data, $offset);
+		$self->{"algorithm"} = $alg;
 
-		@{$self}{qw(inception expiration)} = unpack("\@$offset NN", $$data);
-		$offset += Net::DNS::INT32SZ() + Net::DNS::INT32SZ();
+		my ($inception, $expiration) = unpack("\@$offset NN", $$data);
+		$self->{"inception"} = $inception;
+		$self->{"expiration"} = $expiration;
+		$offset += &Net::DNS::INT32SZ + &Net::DNS::INT32SZ;
 
-		@{$self}{qw(inception expiration)} = unpack("\@$offset nn", $$data);
-		$offset += Net::DNS::INT16SZ() + Net::DNS::INT16SZ();
+		my ($mode, $error) = unpack("\@$offset nn", $$data);
+		$self->{"mode"} = $mode;
+		$self->{"error"} = $error;
+		$offset += &Net::DNS::INT16SZ + &Net::DNS::INT16SZ;
 
 		my ($key_len) = unpack("\@$offset n", $$data);
-		$offset += Net::DNS::INT16SZ();
-		$self->{"key"} = substr($$data, $offset, $key_len);
+		$offset += &Net::DNS::INT16SZ;
+		my $key = substr($$data, $offset, $key_len);
+		$self->{"key"} = $key;
 		$offset += $key_len;
 
 		my ($other_len) = unpack("\@$offset n", $$data);
-		$offset += Net::DNS::INT16SZ();
-		$self->{"other_data"} = substr($$data, $offset, $other_len);
+		$offset += &Net::DNS::INT16SZ;
+		my $otherdata = substr($$data, $offset, $other_len);
+		$self->{"other_data"} = $otherdata;
 		$offset += $other_len;
 	}
 
@@ -86,8 +89,9 @@ sub rdatastr {
 		if ($self->{"other_len"} && defined($self->{"other_data"})) {
 			$rdatastr .= " $self->{other_data}";
 		}
-	} else {
-		$rdatastr = '';
+	}
+	else {
+		$rdatastr = "; no data";
 	}
 
 	return $rdatastr;
